@@ -1,5 +1,5 @@
 #
-# $Id: Qual.pm 15231 2008-12-22 21:51:02Z cjfields $
+# $Id: Qual.pm 16168 2009-09-25 21:07:32Z cjfields $
 #
 # BioPerl module for Bio::DB::Qual
 #
@@ -364,10 +364,6 @@ solution could be to padd them with blank spaces so that each line has the same
 number of characters (maybe this padding should be implemented in
 Bio::SeqIO::qual?).
 
-=head1 SEE ALSO
-
-L<bioperl>
-
 =head1 AUTHOR
 
 Florent E Angly E<lt>florent . angly @ gmail-dot-comE<gt>.  
@@ -422,7 +418,7 @@ These are optional arguments to pass in as well.
                for searching for qual
                files in directories. 
 
- -makeid       A code subroutine for     None
+ -makeid       A code subroutine for     none
                transforming qual IDs.
 
  -maxopen      Maximum size of           32
@@ -448,8 +444,8 @@ sub new {
     my $self = bless {
         debug      => $opts{-debug},
         makeid     => $opts{-makeid},
-        glob       => $opts{-glob} || '*.{qual,QUAL,qa,QA}',
-        maxopen    => $opts{-maxfh}   || 32,
+        glob       => $opts{-glob}    || '*.{qual,QUAL,qa,QA}',
+        maxopen    => $opts{-maxopen} || 32,
         dbmargs    => $opts{-dbmargs} || undef,
         fhcache    => {},
         cacheseq   => {},
