@@ -1,4 +1,4 @@
-# $Id: ProtMatrix.pm 11480 2007-06-14 14:16:21Z sendu $
+# $Id: ProtMatrix.pm 16123 2009-09-17 12:57:27Z cjfields $
 #---------------------------------------------------------
 
 =head1 NAME
@@ -158,6 +158,17 @@ of the Bioperl mailing lists.   Your participation is much appreciated.
   bioperl-l@bioperl.org                  - General discussion
   http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
+=head2 Support 
+
+Please direct usage questions or support issues to the mailing list:
+
+I<bioperl-l@bioperl.org>
+
+rather than to the module maintainer directly. Many experienced and 
+reponsive experts will be able look at the problem and quickly 
+address it. Please include a thorough description of the problem 
+with code and data examples if at all possible.
+
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
